==> libssh-docs-0.11.3-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/group__libssh__auth.js <==
var group__libssh__auth =
[
    [ "ssh_auth_callback", "group__libssh__auth.html#ga3b54d7be70dcc98a107e41e11000a3e1", null ],
    [ "ssh_set_agent_channel", "group__libssh__auth.html#ga5cfc7675941d8f82f6c9d08fb020f40e", null ],
    [ "ssh_set_agent_socket", "group__libssh__auth.html#ga925a9b6033c304eb6dfb426541f84184", null ],
    [ "ssh_userauth_agent", "group__libssh__auth.html#ga7d84f3f89f65455b80b10e2643d80719", null ],
    [ "ssh_userauth_gssapi", "group__libssh__auth.html#ga2758b0e86a848fe0d1d3d263d2a34d28", null ],
    [ "ssh_userauth_kbdint", "group__libssh__auth.html#ga6b3b1c2a045286d9476b0252791a07d2", null ],
    [ "ssh_userauth_kbdint_getanswer", "group__libssh__auth.html#ga4f55ed8bc6f553423ab1c92598d0194b", null ],
    [ "ssh_userauth_kbdint_getinstruction", "group__libssh__auth.html#gae84514d3836cc976535d032edf3becf3", null ],
    [ "ssh_userauth_kbdint_getname", "group__libssh__auth.html#ga5d6f5eb0ed09fe2c7a2ac69b972e130e", null ],
    [ "ssh_userauth_kbdint_getnanswers", "group__libssh__auth.html#ga3a98024f73a8bba6afed0b21de513bcd", null ],
    [ "ssh_userauth_kbdint_getnprompts", "group__libssh__auth.html#gacb996ff4979670db009a71a90172ece9", null ],
    [ "ssh_userauth_kbdint_getprompt", "group__libssh__auth.html#ga15c0f954f79d73e1ac5981ac483efb75", null ],
    [ "ssh_userauth_kbdint_setanswer", "group__libssh__auth.html#ga75e44b1f27059a00080f80fac0107a20", null ],
    [ "ssh_userauth_list", "group__libssh__auth.html#ga35d44897a44b4bb3b7c01108c1812a37", null ],
    [ "ssh_userauth_none", "group__libssh__auth.html#ga58e7c265236edbc97a2f117d3f23b4dd", null ],
    [ "ssh_userauth_password", "group__libssh__auth.html#ga50c0c150f8c4703e7ee49b3e3e3ca215", null ],
    [ "ssh_userauth_publickey", "group__libssh__auth.html#gaa38c4f3194ef36720da7eddb0aa99e23", null ],
    [ "ssh_userauth_publickey_auto", "group__libssh__auth.html#ga53e6771b250c061463ed98b6e5b6e0af", null ],
    [ "ssh_userauth_publickey_auto_get_current_identity", "group__libssh__auth.html#ga85d2105714189775966d3a1cd2903abf", null ],
    [ "ssh_userauth_try_publickey", "group__libssh__auth.html#ga592f673c4d417a6a46cd4876ac8287aa", null ]
];

==> libssh-docs-0.12.0-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/group__libssh__auth.js <==
var group__libssh__auth =
[
    [ "ssh_auth_callback", "group__libssh__auth.html#ga3b54d7be70dcc98a107e41e11000a3e1", null ],
    [ "ssh_set_agent_channel", "group__libssh__auth.html#ga5cfc7675941d8f82f6c9d08fb020f40e", null ],
    [ "ssh_set_agent_socket", "group__libssh__auth.html#ga925a9b6033c304eb6dfb426541f84184", null ],
    [ "ssh_userauth_agent", "group__libssh__auth.html#ga7d84f3f89f65455b80b10e2643d80719", null ],
    [ "ssh_userauth_gssapi", "group__libssh__auth.html#ga2758b0e86a848fe0d1d3d263d2a34d28", null ],
    [ "ssh_userauth_gssapi_keyex", "group__libssh__auth.html#gae22b2fa5d865b8efcbbaba6e7376596b", null ],
    [ "ssh_userauth_kbdint", "group__libssh__auth.html#ga6b3b1c2a045286d9476b0252791a07d2", null ],
    [ "ssh_userauth_kbdint_getanswer", "group__libssh__auth.html#ga4f55ed8bc6f553423ab1c92598d0194b", null ],
    [ "ssh_userauth_kbdint_getinstruction", "group__libssh__auth.html#gae84514d3836cc976535d032edf3becf3", null ],
    [ "ssh_userauth_kbdint_getname", "group__libssh__auth.html#ga5d6f5eb0ed09fe2c7a2ac69b972e130e", null ],
    [ "ssh_userauth_kbdint_getnanswers", "group__libssh__auth.html#ga3a98024f73a8bba6afed0b21de513bcd", null ],
    [ "ssh_userauth_kbdint_getnprompts", "group__libssh__auth.html#gacb996ff4979670db009a71a90172ece9", null ],
    [ "ssh_userauth_kbdint_getprompt", "group__libssh__auth.html#ga15c0f954f79d73e1ac5981ac483efb75", null ],
    [ "ssh_userauth_kbdint_setanswer", "group__libssh__auth.html#ga75e44b1f27059a00080f80fac0107a20", null ],
    [ "ssh_userauth_list", "group__libssh__auth.html#ga35d44897a44b4bb3b7c01108c1812a37", null ],
    [ "ssh_userauth_none", "group__libssh__auth.html#ga58e7c265236edbc97a2f117d3f23b4dd", null ],
    [ "ssh_userauth_password", "group__libssh__auth.html#ga50c0c150f8c4703e7ee49b3e3e3ca215", null ],
    [ "ssh_userauth_publickey", "group__libssh__auth.html#gaa38c4f3194ef36720da7eddb0aa99e23", null ],
    [ "ssh_userauth_publickey_auto", "group__libssh__auth.html#ga53e6771b250c061463ed98b6e5b6e0af", null ],
    [ "ssh_userauth_publickey_auto_get_current_identity", "group__libssh__auth.html#ga85d2105714189775966d3a1cd2903abf", null ],
    [ "ssh_userauth_try_publickey", "group__libssh__auth.html#ga592f673c4d417a6a46cd4876ac8287aa", null ]
];
